pub struct InlineArray<const TCAPACITY: usize, T, TAllocator>where
T: Sized,
TAllocator: Allocator,{ /* private fields */ }Expand description
Represents a dynamic array, where first TCAPACITY items are inlined in the struct itself.
In other words, this array allocates memory only when its length exceeds TCAPACITY. In which
case it allocates data on heap, and becomes pretty much a DynamicArray.
Implementations
Sourceimpl<const TCAPACITY: usize, T, TAllocator> InlineArray<TCAPACITY, T, TAllocator>where
T: Sized,
TAllocator: Allocator,
impl<const TCAPACITY: usize, T, TAllocator> InlineArray<TCAPACITY, T, TAllocator>where
T: Sized,
TAllocator: Allocator,
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new empty InlineArray with the default TAllocator.
Sourcepub const fn with_allocator(allocator: TAllocator) -> Self
pub const fn with_allocator(allocator: TAllocator) -> Self
Creates a new empty InlineArray with the given TAllocator.
Sourcepub fn with_capacity(capacity: Length) -> Result<Self, ArrayError>
pub fn with_capacity(capacity: Length) -> Result<Self, ArrayError>
Creates a new InlineArray with the default TAllocator. This method allocates memory
if capacity exceeds TCAPACITY.
Errors
For details see ArrayError.
Sourcepub fn with_capacity_and_allocator(
capacity: Length,
allocator: TAllocator,
) -> Result<Self, ArrayError>
pub fn with_capacity_and_allocator( capacity: Length, allocator: TAllocator, ) -> Result<Self, ArrayError>
Creates a new InlineArray with the given TAllocator. This method allocates memory
if capacity exceeds TCAPACITY.
Errors
For details see ArrayError.